package com.cmx.hydrology.activity;

import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;

import androidx.annotation.RequiresApi;
import androidx.navigation.NavController;
import androidx.navigation.Navigation;
import androidx.navigation.ui.NavigationUI;

import com.cmx.hydrology.R;
import com.cmx.hydrology.constant.Events;
import com.cmx.hydrology.databinding.ActivityMainBinding;
import com.google.android.material.bottomnavigation.BottomNavigationView;
import com.lsxiao.apollo.core.Apollo;
import com.lsxiao.apollo.core.annotations.Receive;

public class MainActivity extends BaseActivity {

    private ActivityMainBinding binding;
    private BottomNavigationView navView;
    private NavController navController;


    @RequiresApi(api = Build.VERSION_CODES.M)
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        navView = findViewById(R.id.nav_view);
        navController = Navigation.findNavController(this, R.id.nav_host_fragment_activity_main);
        NavigationUI.setupWithNavController(binding.navView, navController);
    }


    /**
     * 显示tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_SHOW)
    public void showTab() {
        binding.navView.setVisibility(View.VISIBLE);
    }

    /**
     * 隐藏tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_HIDE)
    public void hideTab() {
        binding.navView.setVisibility(View.GONE);
    }


    /**
     * 打开新的web
     */
    @Receive(Events.JS_OPEN_OPEN_WEB)
    public void openWeb(String url) {
        Intent intent = new Intent(this, WebActivity.class);
        intent.putExtra("url", url);
        startActivity(intent);
    }


    /**
     * 选择tab
     */
    @Receive(Events.JS_OPEN_TAB)
    public void ckTab(String mode) {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB);
        switch (mode) {
            case "1":
                Menu menu = navView.getMenu();
                MenuItem menuItem = menu.getItem(0); // 将index替换为您想要点击的项目的索引
                menuItem.setChecked(true);
                navController.navigate(R.id.navigation_home);
                break;
            case "2":
                Menu menu2 = navView.getMenu();
                MenuItem menuItem2 = menu2.getItem(1); // 将index替换为您想要点击的项目的索引
                menuItem2.setChecked(true);
                navController.navigate(R.id.navigation_msg);
                break;
            case "3":
                Menu menu3 = navView.getMenu();
                MenuItem menuItem3 = menu3.getItem(2); // 将index替换为您想要点击的项目的索引
                menuItem3.setChecked(true);
                navController.navigate(R.id.navigation_map);
                break;
            case "4":
                Menu menu4 = navView.getMenu();
                MenuItem menuItem4 = menu4.getItem(3); // 将index替换为您想要点击的项目的索引
                menuItem4.setChecked(true);
                navController.navigate(R.id.navigation_my);
                break;
        }
    }


    /**
     * 退出登录
     */
    @Receive(Events.JS_OPEN_LOGOUT)
    public void exit() {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB);
        finish();
        Intent intent = new Intent(this, LoginActivity.class);
        startActivity(intent);
    }
}